Class: FaaStRuby::Command::Help

Inherits:
BaseCommand show all
Defined in:
lib/faastruby/cli/commands/help.rb

Instance Method Summary collapse

Methods inherited from BaseCommand

#has_user_logged_in?, #help, #load_credentials, #load_yaml, #say, spin, #spin, #write_file

Constructor Details

#initialize(args) ⇒ Help

Returns a new instance of Help.



5
6
7
# File 'lib/faastruby/cli/commands/help.rb', line 5

def initialize(args)
  @args = args
end

Instance Method Details

#runObject



9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/faastruby/cli/commands/help.rb', line 9

def run
  puts "FaaStRuby CLI - Manage workspaces and functions hosted at faastruby.io"
  puts "Version: #{FaaStRuby::VERSION}"
  puts
  puts "Usage: faastruby [OPTIONS] COMMAND [--help | -h] [ARGS]"
  puts
  puts "OPTIONS:"
  puts 'help, -h, --help     # Displays this help'
  puts '-v                   # Print version and exit'
  puts '--region tor1        # Specify a region. "tor1" (default) is the only region available'
  puts "\nCOMMANDS:"
  puts %(
Accounts:
  signup
  confirm-account      # Send a token over email for account confirmation
  login
  logout

Functions:
  new                  # Initialize a function in your local machine
  deploy-to            # Deploy a function to a cloud workspace
  remove-from          # Remove a function from a cloud workspace
  run                  # Trigger the function via HTTP endpoint
  update-context       # Update the context data for a function

Projects:
  new-project          # Initialize a project in your local machine
  deploy               # Deploy all functions and static files of a project

Workspaces:
  create-workspace     # Create a cloud workspace
  destroy-workspace    # Erase a workspace from the cloud
  list-workspace       # List what's in a cloud workspace
  cp                   # Copy a static file from your local machine to a cloud workspace
  rm                   # Remove a static file from a cloud workspace
  update-workspace     # Update workspace settings

)
  puts "Run faastruby COMMAND --help for more details."
end